@@ -73,32 +73,30 @@ class SCELoss(WeightedBaseLoss):
         yhat_soft = F.softmax(yhat, dim=1) + self.eps
         assert target_one_hot.shape == yhat.shape
 
-        yhat = torch.clamp(yhat_soft, min=1e-7, max=1.0)
-        target_one_hot = torch.clamp(target_one_hot, min=1e-4, max=1.0)
+        if self.apply_svls:
+            target_one_hot = self.apply_svls_to_target(
+                target_one_hot, num_classes, **kwargs
+            )
+
+        if self.apply_ls:
+            target_one_hot = self.apply_ls_to_target(
+                target_one_hot, num_classes, **kwargs
+            )
 
         forward = target_one_hot * torch.log(yhat_soft)
         reverse = yhat_soft * torch.log(target_one_hot)
 
         cross_entropy = -torch.sum(forward, dim=1)  # to (B, H, W)
         reverse_cross_entropy = -torch.sum(reverse, dim=1)  # to (B, H, W)
-
-        if self.class_weights is not None:
-            cross_entropy = self.apply_class_weights(cross_entropy, target)
-            reverse_cross_entropy = self.apply_class_weights(
-                reverse_cross_entropy, target
-            )
-
-        if self.edge_weight is not None:
-            cross_entropy = self.apply_edge_weights(cross_entropy, target_weight)
-            reverse_cross_entropy = self.apply_edge_weights(
-                reverse_cross_entropy, target_weight
-            )
-
-        loss = (
-            self.alpha * cross_entropy.mean() + self.beta * reverse_cross_entropy.mean()
-        )
+        loss = self.alpha * cross_entropy + self.beta * reverse_cross_entropy
 
         if self.apply_sd:
             loss = self.apply_spectral_decouple(loss, yhat)
 
-        return loss
+        if self.class_weights is not None:
+            loss = self.apply_class_weights(loss, target)
+
+        if self.edge_weight is not None:
+            loss = self.apply_edge_weights(loss, target_weight)
+
+        return loss.mean()
