@@ -59,6 +59,7 @@ __all__ = [
     "majority_vote_sequential",
     "med_filt_parallel",
     "med_filt_sequential",
+    "intersection",
 ]
 
 
@@ -195,7 +196,9 @@ def fix_duplicates(inst_map: np.ndarray) -> np.ndarray:
     """
     current_max_id = np.amax(inst_map)
     inst_list = list(np.unique(inst_map))
-    inst_list.remove(0)  # 0 is background
+    if 0 in inst_list:
+        inst_list.remove(0)
+
     for inst_id in inst_list:
         inst = np.array(inst_map == inst_id, np.uint8)
         remapped_ids = ndi.label(inst)[0]
@@ -1014,3 +1017,34 @@ def med_filt_sequential(sem_map: np.ndarray, kernel_width: int = 15) -> np.ndarr
         sem[i] = rank.median(sem_map[i], footprint=square(kernel_width))
 
     return sem
+
+
+@njit(cache=True, fastmath=True)
+def intersection(boxA: np.ndarray, boxB: np.ndarray):
+    """Compute area of intersection of two boxes.
+
+    Parameters
+    ----------
+        boxA : np.ndarray
+            First boxes
+        boxB : np.ndarray
+            Second box
+
+    Returns
+    -------
+        float64:
+            Area of intersection
+    """
+    xA = max(boxA[..., 0], boxB[..., 0])
+    xB = min(boxA[..., 2], boxB[..., 2])
+    dx = xB - xA
+    if dx <= 0:
+        return 0.0
+
+    yA = max(boxA[..., 1], boxB[..., 1])
+    yB = min(boxA[..., 3], boxB[..., 3])
+    dy = yB - yA
+    if dy <= 0.0:
+        return 0.0
+
+    return dx * dy
